AicError

Enum AicError 

pub enum AicError {
Show 18 variants ParameterOutOfRange, NotInitialized, AudioConfigUnsupported, AudioConfigMismatch, ProcessingNotAllowed, Internal, LicenseFormatInvalid, LicenseVersionUnsupported, LicenseExpired, TokenUpdateUnsupported, ModelInvalid, ModelVersionUnsupported, ModelTypeUnsupported, FilePathInvalid, FileSystemError, ModelDataUnaligned, ModelDownload(String), Unknown(Type),
}
Error type for AIC SDK operations.

Variants



ParameterOutOfRange

Parameter value is outside the acceptable range. Check documentation for valid values.



NotInitialized

Handle must be initialized before calling this operation.



AudioConfigUnsupported

Audio configuration (sample_rate, block_size) is not supported by the model



AudioConfigMismatch

Audio block configuration differs from the one provided during initialization



ProcessingNotAllowed

Processing is not allowed because the SDK key was not authorized or usage reporting failed.



Internal

Internal error occurred. Contact support.



LicenseFormatInvalid

License key format is invalid or corrupted. Verify the key was copied correctly.



LicenseVersionUnsupported

License version is not compatible with the SDK version. Update SDK or contact support.



LicenseExpired

License key has expired. Renew your license to continue.



TokenUpdateUnsupported

Updating the token is only supported when both the original and new keys are JWT-form licenses.



ModelInvalid

The model file is invalid or corrupted. Verify the file is correct.



ModelVersionUnsupported

The model file version is not compatible with this SDK version.



ModelTypeUnsupported

The model type is not supported by the requested API.



FilePathInvalid

The file path is invalid.



FileSystemError

The model file cannot be opened due to a filesystem error. Verify that the file exists.



ModelDataUnaligned

The model data is not aligned to 64 bytes.



ModelDownload(String)

Model download error.



Unknown(Type)

Unknown error code.