AnalysisResult

Struct AnalysisResult 

pub struct AnalysisResult {
    pub risk_score: f32,
    pub speaker_reverb: f32,
    pub speaker_loudness: f32,
    pub interfering_speech: f32,
    pub media_speech: f32,
    pub noise: f32,
    pub packet_loss: f32,
}
The result of analyzing an audio signal with an Analyzer.

Scores are in the range 0.0..=1.0. For all fields except speaker_loudness, lower values indicate less problematic audio.

Fields

risk_score: f32

Headline audio score.

Predicts likelihood of failure of downstream models including speech-to-text, voice activity detection or turn-taking or speech-to-speech models. Lower indicates less problematic audio.

Range: 0.0 to 1.0

speaker_reverb: f32

Measure of speaker distance and reverberance. Lower indicates less problematic audio.

Range: 0.0 to 1.0

speaker_loudness: f32

Measure of speaker loudness.

Range: 0.0 to 1.0

interfering_speech: f32

Measure of interference from additional speakers present in audio. Lower indicates less problematic audio.

Range: 0.0 to 1.0

media_speech: f32

Measure of interfering speech content from media devices, e.g. from TVs, radios, phones or else. Lower indicates less problematic audio.

Range: 0.0 to 1.0

noise: f32

Measure of ambient or environmental noise. Lower indicates less problematic audio.

Range: 0.0 to 1.0

packet_loss: f32

Measure of audio dropouts or discontinuities in the stream, e.g. from packet loss, frame erasure, jitter or CPU overload. Lower indicates less problematic audio.

Range: 0.0 to 1.0